summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClaude Paroz <claude@2xlibre.net>2013-12-06 09:59:30 +0100
committerClaude Paroz <claude@2xlibre.net>2013-12-06 10:00:09 +0100
commit482ca0cecc93a76cbcbfbf784f56db160b2e5cfc (patch)
tree1b953e27821ab4c315d8ab46a38ce56e002691df
parent4d0c72eb68fc6518ef02c757b37e5548d0007f41 (diff)
Renamed syncdb to migrate in spatialite backend
-rw-r--r--django/contrib/gis/db/backends/spatialite/creation.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/django/contrib/gis/db/backends/spatialite/creation.py b/django/contrib/gis/db/backends/spatialite/creation.py
index fb3606f7e9..521985259e 100644
--- a/django/contrib/gis/db/backends/spatialite/creation.py
+++ b/django/contrib/gis/db/backends/spatialite/creation.py
@@ -13,7 +13,7 @@ class SpatiaLiteCreation(DatabaseCreation):
database already exists. Returns the name of the test database created.
This method is overloaded to load up the SpatiaLite initialization
SQL prior to calling the `syncdb` command.
"""
# Don't import django.core.management if it isn't needed.
from django.core.management import call_command
@@ -31,13 +31,13 @@ class SpatiaLiteCreation(DatabaseCreation):
self.connection.close()
self.connection.settings_dict["NAME"] = test_database_name
# Need to load the SpatiaLite initialization SQL before running `syncdb`.
self.load_spatialite_sql()
# Report syncdb messages at one level lower than that requested.
# This ensures we don't get flooded with messages during testing
# (unless you really ask to be flooded)
- call_command('syncdb',
+ call_command('migrate',
verbosity=max(verbosity - 1, 0),
interactive=False,
database=self.connection.alias,
@@ -47,7 +47,7 @@ class SpatiaLiteCreation(DatabaseCreation):
# custom SQL has been removed. The only test data should come from
# test fixtures, or autogenerated from post_migrate triggers.
# This has the side effect of loading initial data (which was
# intentionally skipped in the syncdb).
call_command('flush',
verbosity=max(verbosity - 1, 0),
interactive=False,
@@ -13,7 +13,7 @@ class SpatiaLiteCreation(DatabaseCreation):
database already exists. Returns the name of the test database created.
This method is overloaded to load up the SpatiaLite initialization
- SQL prior to calling the `syncdb` command.
+ SQL prior to calling the `migrate` command.
"""
# Don't import django.core.management if it isn't needed.
@@ -31,13 +31,13 @@ class SpatiaLiteCreation(DatabaseCreation):
self.connection.close()
self.connection.settings_dict["NAME"] = test_database_name
- # Need to load the SpatiaLite initialization SQL before running `syncdb`.
+ # Need to load the SpatiaLite initialization SQL before running `migrate`.
self.load_spatialite_sql()
@@ -31,13 +31,13 @@ class SpatiaLiteCreation(DatabaseCreation):
self.load_spatialite_sql()
- # Report syncdb messages at one level lower than that requested.
+ # Report migrate messages at one level lower than that requested.
# This ensures we don't get flooded with messages during testing
# (unless you really ask to be flooded)
@@ -47,7 +47,7 @@ class SpatiaLiteCreation(DatabaseCreation):
# test fixtures, or autogenerated from post_migrate triggers.
# This has the side effect of loading initial data (which was
- # intentionally skipped in the syncdb).
+ # intentionally skipped in the migrate).
call_command('flush',
verbosity=max(verbosity - 1, 0),